summaryrefslogtreecommitdiffstats
path: root/kbabel/filters/linguist/linguistimport.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/filters/linguist/linguistimport.cpp')
-rw-r--r--kbabel/filters/linguist/linguistimport.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kbabel/filters/linguist/linguistimport.cpp b/kbabel/filters/linguist/linguistimport.cpp
index a1870bd7..b46f5f97 100644
--- a/kbabel/filters/linguist/linguistimport.cpp
+++ b/kbabel/filters/linguist/linguistimport.cpp
@@ -1,4 +1,4 @@
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
/* ****************************************************************************
This file is part of KBabel
@@ -26,18 +26,18 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
**************************************************************************** */
// Qt include files
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqobject.h>
@@ -55,12 +55,12 @@ K_EXPORT_COMPONENT_FACTORY( kbabel_linguistimport, KGenericFactory<LinguistImpor
using namespace KBabel;
-LinguistImportPlugin::LinguistImportPlugin( TQObject * parent, const char * name, const TQStringList& )
- : CatalogImportPlugin( parent, name )
+LinguistImportPlugin::LinguistImportPlugin( TQObject * tqparent, const char * name, const TQStringList& )
+ : CatalogImportPlugin( tqparent, name )
{
}
-ConversionStatus LinguistImportPlugin::load( const TQString& filename, const TQString& )
+ConversiontqStatus LinguistImportPlugin::load( const TQString& filename, const TQString& )
{
if ( filename.isEmpty( ) ) {
kdDebug( ) << "fatal error: empty filename to open" << endl;
@@ -113,9 +113,9 @@ ConversionStatus LinguistImportPlugin::load( const TQString& filename, const TQS
return OK;
}
-void LinguistImportPlugin::parse( const TQDomElement& parentElement )
+void LinguistImportPlugin::parse( const TQDomElement& tqparentElement )
{
- TQDomNode node = parentElement.firstChild( );
+ TQDomNode node = tqparentElement.firstChild( );
while ( !node.isNull( ) ) {
if ( node.isElement( ) ) {
@@ -26,18 +26,18 @@
your version.
**************************************************************************** */
-// Qt include files
+// TQt include files
#include <tqfile.h>
#include <tqfileinfo.h>